@@ -1,4 +1,4 @@
-/*	$NetBSD: el.c,v 1.15 1999/11/12 01:05:07 lukem Exp $	*/
+/*	$NetBSD: el.c,v 1.16 2000/05/15 12:15:38 christos Exp $	*/
 
 /*-
  * Copyright (c) 1992, 1993
@@ -404,7 +404,7 @@ el_source(el, fname)
 	return -1;
 
     while ((ptr = fgetln(fp, &len)) != NULL) {
-	if (ptr[len - 1] == '\n')
+	if (len > 0 && ptr[len - 1] == '\n')
 	    --len;
 	ptr[len] = '\0';
 	if (parse_line(el, ptr) == -1) {
