@@ -1,4 +1,4 @@
-/*	$NetBSD: term.c,v 1.20 2000/01/20 22:56:22 christos Exp $	*/
+/*	$NetBSD: term.c,v 1.22 2000/06/02 13:37:12 lukem Exp $	*/
 
 /*-
  * Copyright (c) 1992, 1993
@@ -499,7 +499,7 @@ term_move_to_line(el, where)
 	    if (EL_HAS_AUTO_MARGINS &&
 		el->el_display[el->el_cursor.v][0] != '\0') {
 		/* move without newline */
-		term_move_to_char(el, el->el_term.t_size.h);
+		term_move_to_char(el, el->el_term.t_size.h-1);
 		term_overwrite(el,
 		    &el->el_display[el->el_cursor.v][el->el_cursor.h], 1);
 		/* updates Cursor */
@@ -1278,7 +1278,15 @@ term_settc(el, argc, argv)
 	    return 0;
 	}
 	else {
-	    el->el_term.t_val[tv - tval] = atoi(how);
+	    long i;
+	    char *ep;
+
+	    i = strtol(how, &ep, 10);
+	    if (*ep != '\0') {
+		(void) fprintf(el->el_errfile, "settc: Bad value `%s'.\n", how);
+		return -1;
+	    }
+	    el->el_term.t_val[tv - tval] = (int)i;
 	    el->el_term.t_size.v = Val(T_co);
 	    el->el_term.t_size.h = Val(T_li);
 	    if (tv == &tval[T_co] || tv == &tval[T_li])
@@ -1300,13 +1308,14 @@ term_echotc(el, argc, argv)
     int argc;
     char **argv;
 {
-    char   *cap, *scap;
+    char   *cap, *scap, *ep;
     int     arg_need, arg_cols, arg_rows;
     int     verbose = 0, silent = 0;
     char   *area;
     static char *fmts = "%s\n", *fmtd = "%d\n";
     struct termcapstr *t;
     char    buf[TC_BUFSIZE];
+    long    i;
 
     area = buf;
 
@@ -1442,7 +1451,14 @@ term_echotc(el, argc, argv)
 	    return -1;
 	}
 	arg_cols = 0;
-	arg_rows = atoi(*argv);
+	i = strtol(*argv, &ep, 10);
+	if (*ep != '\0' || i < 0) {
+	    if (!silent)
+		(void) fprintf(el->el_errfile,
+		    "echotc: Bad value `%s' for rows.\n", *argv);
+	    return -1;
+	}
+	arg_rows = (int)i;
 	argv++;
 	if (*argv && *argv[0]) {
 	    if (!silent)
@@ -1467,7 +1483,14 @@ term_echotc(el, argc, argv)
 		    "echotc: Warning: Missing argument.\n");
 	    return -1;
 	}
-	arg_cols = atoi(*argv);
+	i = strtol(*argv, &ep, 10);
+	if (*ep != '\0' || i < 0) {
+	    if (!silent)
+		(void) fprintf(el->el_errfile,
+		    "echotc: Bad value `%s' for cols.\n", *argv);
+	    return -1;
+	}
+	arg_cols = (int)i;
 	argv++;
 	if (!*argv || *argv[0] == '\0') {
 	    if (!silent)
@@ -1475,7 +1498,20 @@ term_echotc(el, argc, argv)
 		    "echotc: Warning: Missing argument.\n");
 	    return -1;
 	}
-	arg_rows = atoi(*argv);
+	i = strtol(*argv, &ep, 10);
+	if (*ep != '\0' || i < 0) {
+	    if (!silent)
+		(void) fprintf(el->el_errfile,
+		    "echotc: Bad value `%s' for rows.\n", *argv);
+	    return -1;
+	}
+	arg_rows = (int)i;
+	if (*ep != '\0') {
+	    if (!silent)
+		(void) fprintf(el->el_errfile,
+		    "echotc: Bad value `%s'.\n", *argv);
+	    return -1;
+	}
 	argv++;
 	if (*argv && *argv[0]) {
 	    if (!silent)
