@@ -1,4 +1,4 @@
-/*	$Id: snprintf.c,v 1.9 1999/10/11 13:00:54 lukem Exp $	*/
+/*	$Id: snprintf.c,v 1.10 2000/06/04 14:46:07 lukem Exp $	*/
 
 /*
  * Copyright Patrick Powell 1995
@@ -72,16 +72,15 @@
 #define LLONG long
 #endif
 
-static void dopr __P((char *buffer, size_t maxlen, size_t *retlen,
-		    const char *format, va_list args));
-static void fmtstr __P((char *buffer, size_t * currlen, size_t maxlen,
-		    char *value, int flags, int min, int max));
-static void fmtint __P((char *buffer, size_t * currlen, size_t maxlen,
-		    LLONG value, int base, int min, int max, int flags));
-static void fmtfp __P((char *buffer, size_t * currlen, size_t maxlen,
-		    LDOUBLE fvalue, int min, int max, int flags));
-static void dopr_outch __P((char *buffer, size_t * currlen, size_t maxlen,
-		    int c));
+static void dopr(char *buffer, size_t maxlen, size_t *retlen,
+		    const char *format, va_list args);
+static void fmtstr(char *buffer, size_t * currlen, size_t maxlen,
+		    char *value, int min, int max, int flags);
+static void fmtint(char *buffer, size_t * currlen, size_t maxlen,
+		    LLONG value, int base, int min, int max, int flags);
+static void fmtfp(char *buffer, size_t * currlen, size_t maxlen,
+		    LDOUBLE fvalue, int min, int max, int flags);
+static void dopr_outch(char *buffer, size_t * currlen, size_t maxlen, int c);
 
 /*
  * dopr(): poor man's version of doprintf
@@ -115,12 +114,8 @@ static void dopr_outch __P((char *buffer, size_t * currlen, size_t maxlen,
 #define char_to_int(p) (p - '0')
 
 static void
-dopr(buffer, maxlen, retlen, format, args)
-	char		*buffer;
-	size_t		 maxlen;
-	size_t		*retlen;
-	const char	*format;
-	va_list		 args;
+dopr(char *buffer, size_t maxlen, size_t *retlen, const char *format,
+	va_list args)
 {
 	char	 ch;
 	LLONG	 value;
@@ -318,7 +313,7 @@ dopr(buffer, maxlen, retlen, format, args)
 				if (max < 0)
 					max = maxlen;	/* ie, no max */
 				fmtstr(buffer, &currlen, maxlen, strvalue,
-				    flags, min, max);
+				    min, max, flags);
 				break;
 			case 'p':
 				value = (long)va_arg(args, void *);
@@ -375,14 +370,8 @@ dopr(buffer, maxlen, retlen, format, args)
 }
 
 static void
-fmtstr(buffer, currlen, maxlen, value, flags, min, max)
-	char	*buffer;
-	size_t	*currlen;
-	size_t	 maxlen;
-	char	*value;
-	int	 flags;
-	int	 min;
-	int	 max;
+fmtstr(char *buffer, size_t *currlen, size_t maxlen, char *value, int flags,
+	int min, int max)
 {
 	int	padlen, strln;	/* amount to pad */
 	int	cnt = 0;
@@ -416,15 +405,8 @@ fmtstr(buffer, currlen, maxlen, value, flags, min, max)
 /* Have to handle DP_F_NUM (ie 0x and 0 alternates) */
 
 static void
-fmtint(buffer, currlen, maxlen, value, base, min, max, flags)
-	char	*buffer;
-	size_t	*currlen;
-	size_t	 maxlen;
-	LLONG	 value;
-	int	 base;
-	int	 min;
-	int	 max;
-	int	 flags;
+fmtint(char *buffer, size_t *currlen, size_t maxlen, LLONG value, int base,
+	int min, int max, int flags)
 {
 	int		signvalue = 0;
 	unsigned LLONG	uvalue;
@@ -508,8 +490,7 @@ fmtint(buffer, currlen, maxlen, value, base, min, max, flags)
 }
 
 static LDOUBLE
-abs_val(value)
-	LDOUBLE	value;
+abs_val(LDOUBLE value)
 {
 	LDOUBLE	result = value;
 
@@ -520,8 +501,7 @@ abs_val(value)
 }
 
 static LDOUBLE
-pow10(exp)
-	int	exp;
+pow10(int exp)
 {
 	LDOUBLE	result = 1;
 
@@ -534,8 +514,7 @@ pow10(exp)
 }
 
 static long
-round(value)
-	LDOUBLE	value;
+round(LDOUBLE value)
 {
 	long	intpart;
 
@@ -548,14 +527,8 @@ round(value)
 }
 
 static void
-fmtfp(buffer, currlen, maxlen, fvalue, min, max, flags)
-	char	*buffer;
-	size_t	*currlen;
-	size_t	 maxlen;
-	LDOUBLE	 fvalue;
-	int	 min;
-	int	 max;
-	int	 flags;
+fmtfp(char *buffer, size_t *currlen, size_t maxlen, LDOUBLE fvalue,
+	int min, int max, int flags)
 {
 	int	signvalue = 0;
 	LDOUBLE	ufvalue;
@@ -688,22 +661,14 @@ fmtfp(buffer, currlen, maxlen, fvalue, min, max, flags)
 }
 
 static void
-dopr_outch(buffer, currlen, maxlen, c)
-	char	*buffer;
-	size_t	*currlen;
-	size_t	 maxlen;
-	int	 c;
+dopr_outch(char *buffer, size_t *currlen, size_t maxlen, int c)
 {
 	if (*currlen < maxlen)
 		buffer[(*currlen)++] = (char)c;
 }
 
 int
-vsnprintf(str, count, fmt, args)
-	char		*str;
-	size_t		 count;
-	const char	*fmt;
-	va_list		 args;
+vsnprintf(char *str, size_t count, const char *fmt, va_list args)
 {
 	size_t retlen;
 
@@ -714,27 +679,12 @@ vsnprintf(str, count, fmt, args)
 
 /* VARARGS3 */
 int
-#ifdef __STDC__
 snprintf(char *str, size_t count, const char *fmt, ...)
-#else
-snprintf(str, count, va_alist)
-	char	*str;
-	size_t	 count;
-	va_dcl
-#endif
 {
-#ifndef __STDC__
-	char	*fmt;
-#endif
 	va_list	 ap;
 	int	 rv;
 
-#ifdef __STDC__
 	va_start(ap, fmt);
-#else
-	va_start(ap);
-	fmt = va_arg(ap, char *);
-#endif
 	rv = vsnprintf(str, count, fmt, ap);
 	va_end(ap);
 	return (rv);
@@ -747,9 +697,7 @@ snprintf(str, count, va_alist)
 #endif
 
 int
-main(argc, argv)
-	int	 argc;
-	char	*argv[];
+main(int argc, char *argv[])
 {
 	char	 buf1[LONG_STRING];
 	char	 buf2[LONG_STRING];
