@@ -1,7 +1,7 @@
-/* $Id: lukemftp.h,v 1.22 2000/06/05 11:10:18 lukem Exp $ */
+/* $Id: lukemftp.h,v 1.25 2000/07/09 14:31:17 lukem Exp $ */
 
 #define	FTP_PRODUCT	"lukemftp"
-#define	FTP_VERSION	"1.3"
+#define	FTP_VERSION	"1.4"
 
 #include "config.h"
 
@@ -193,7 +193,7 @@ int	mkstemp(const char *);
 int	snprintf(char *, size_t, const char *, ...);
 #endif
 
-#if ! HAVE_STRSUP
+#if ! HAVE_STRDUP
 char   *strdup(const char *);
 #endif
 
