@@ -1,4 +1,4 @@
-/*	$NetBSD: ftp.c,v 1.98 2000/06/05 09:22:53 lukem Exp $	*/
+/*	$NetBSD: ftp.c,v 1.100 2000/06/11 15:15:52 lukem Exp $	*/
 
 /*-
  * Copyright (c) 1996-2000 The NetBSD Foundation, Inc.
@@ -1467,6 +1467,7 @@ reinit:
 #define	pack4(var, off) \
 	(((var[(off) + 0] & 0xff) << 24) | ((var[(off) + 1] & 0xff) << 16) | \
 	 ((var[(off) + 2] & 0xff) << 8) | ((var[(off) + 3] & 0xff) << 0))
+#define	UC(b)	(((int)b)&0xff)
 
 		/*
 		 * What we've got at this point is a string of comma separated
@@ -1565,12 +1566,11 @@ reinit:
 				data_addr.su_family = AF_INET6;
 				data_addr.su_len = sizeof(struct sockaddr_in6);
 			    {
-				u_int32_t *p32;
-				p32 = (u_int32_t *)&data_addr.su_sin6.sin6_addr;
-				p32[0] = htonl(pack4(addr, 0));
-				p32[1] = htonl(pack4(addr, 4));
-				p32[2] = htonl(pack4(addr, 8));
-				p32[3] = htonl(pack4(addr, 12));
+				int i;
+				for (i = 0; i < sizeof(struct in6_addr); i++) {
+					data_addr.su_sin6.sin6_addr.s6_addr[i] =
+					    UC(addr[i]);
+				}
 			    }
 				data_addr.su_port = htons(pack2(port, 0));
 				break;
@@ -1668,8 +1668,6 @@ noport:
 	if (xlisten(data, 1) < 0)
 		warn("listen");
 
-#define	UC(b)	(((int)b)&0xff)
-
 	if (sendport) {
 #ifdef INET6
 		char hname[INET6_ADDRSTRLEN];
@@ -2178,6 +2176,7 @@ ai_unmapped(struct addrinfo *ai)
 #ifdef INET6
 	struct sockaddr_in6 *sin6;
 	struct sockaddr_in sin;
+	int len;
 
 	if (ai->ai_family != AF_INET6)
 		return;
@@ -2190,13 +2189,16 @@ ai_unmapped(struct addrinfo *ai)
 
 	memset(&sin, 0, sizeof(sin));
 	sin.sin_family = AF_INET;
-	sin.sin_len = sizeof(struct sockaddr_in);
+	len = sizeof(struct sockaddr_in);
 	memcpy(&sin.sin_addr, &sin6->sin6_addr.s6_addr[12],
 	    sizeof(sin.sin_addr));
 	sin.sin_port = sin6->sin6_port;
 
 	ai->ai_family = AF_INET;
-	memcpy(ai->ai_addr, &sin, sin.sin_len);
-	ai->ai_addrlen = sin.sin_len;
+#ifdef BSD4_4
+	sin.sin_len = len;
+#endif
+	memcpy(ai->ai_addr, &sin, len);
+	ai->ai_addrlen = len;
 #endif
 }
